library(maptools)

metals<-read.csv("metals.csv",header=T)

metal.sel<-metals[,1:67]
names(metal.sel)<-sub("\\..*$","",names(metal.sel))
metal.sel[metal.sel < 0] <- 0
metal.sel <- metal.sel[, -which(colSums(is.na(metal.sel)) > 10)]
metal.sel <- na.omit(metal.sel) #exclude all NA rows

corenames <- c("Erie Central", "Erie West", "Huron South", "Huron North", "Michigan North", "Michigan South", 
               "Ontario East","Ontario West", "Superior Isle Royale","Superior East", "Superior West")
colo <- c("darkolivegreen1", "chartreuse4", "yellow","orange", "gray88", "gray 47", "indianred","red4", 
          "cyan","cornflowerblue","blue4")

############################################################################

pdf("All Lakes PCA.pdf")

metal.pca<-prcomp(metal.sel[,-c(1:5)], scale= TRUE)
plot(metal.pca$x,main= "PCA", type="n", ylim= c(-6,10), xlim= c(-15, 10))
abline(h=0,lty=2)
abline(v=0,lty=2)

sites<-levels(droplevels(metal.sel$Location))
for (j in 1:length(sites)) {
  lines(metal.pca$x[metal.sel$Location==sites[j],1],
        metal.pca$x[metal.sel$Location==sites[j],2],col=colo[j],
        lwd=2)
        
  text(max(metal.pca$x[metal.sel$Location==sites[j],1]),
       max(metal.pca$x[metal.sel$Location==sites[j],2]),
       labels=round(max(metal.sel[metal.sel$Location==sites[j],"date"]),0),col=colo[j],cex=0.7) 
  
  text(min(metal.pca$x[metal.sel$Location==sites[j],1]),
       min(metal.pca$x[metal.sel$Location==sites[j],2]),
       labels=round(min(metal.sel[metal.sel$Location==sites[j],"date"]),0),col=colo[j],cex=0.7)   
}

pointLabel(x=10*metal.pca$rotation[,1]*metal.pca$sdev[1],y=10*metal.pca$rotation[,2]*metal.pca$sdev[2],
           labels=rownames(metal.pca$rotation),cex=0.7,method="SANN",allowSmallOverlap=FALSE,col="black",font=3)


legend("topleft",legend=corenames,lty=1,col=colo, lwd=2)



dev.off()




